
;**************************************************************************
;*                         Vianocna Siska                                 *
;**************************************************************************
;*          3 LEDs (GP0, GP1, GP2)                                        *
;**************************************************************************
;*          v 1.04 - 20.10.2012                                           *
;**************************************************************************
;*          Hardw.: PIC10F202 used                                        *
;*          OSC.......: Internal osc. used     POWER.....:  3x1,5V        *
;**************************************************************************



;==========================================================================
;
;       Register Definitions
;
;==========================================================================

W                            EQU     H'0000'
F                            EQU     H'0001'

;----- Register Files -----------------------------------------------------

INDF                         EQU     H'0000'
TMR0                         EQU     H'0001'
PCL                          EQU     H'0002'
STATUS                       EQU     H'0003'
FSR                          EQU     H'0004'
OSCCAL                       EQU     H'0005'
GPIO                         EQU     H'0006'


;----- STATUS Bits --------------------------------------------------------

GPWUF                        EQU     H'0007'
NOT_TO                       EQU     H'0004'
NOT_PD                       EQU     H'0003'
Z                            EQU     H'0002'
DC                           EQU     H'0001'
C                            EQU     H'0000'

;----- OPTION Bits --------------------------------------------------------

NOT_GPWU                     EQU     H'0007'
NOT_GPPU                     EQU     H'0006'
T0CS                         EQU     H'0005'
T0SE                         EQU     H'0004'
PSA                          EQU     H'0003'
PS2                          EQU     H'0002'
PS1                          EQU     H'0001'
PS0                          EQU     H'0000'

;----- OSCCAL Bits --------------------------------------------------------

CAL6                         EQU     H'0007'
CAL5                         EQU     H'0006'
CAL4                         EQU     H'0005'
CAL3                         EQU     H'0004'
CAL2                         EQU     H'0003'
CAL1                         EQU     H'0002'
CAL0			     EQU     H'0001'
FOSC4			     EQU     H'0000'



;==========================================================================
;
;       RAM Definition
;
;==========================================================================

        __MAXRAM H'1F'
	__BADRAM H'07'

;==========================================================================
;
;       Configuration Bits
;
;==========================================================================

_MCLRE_ON                    EQU     H'0FFF'
_MCLRE_OFF                   EQU     H'0FEF'
_CP_ON                       EQU     H'0FF7'
_CP_OFF                      EQU     H'0FFF'
_WDT_ON                      EQU     H'0FFF'
_WDT_OFF                     EQU     H'0FFB'
_IntRC_OSC                   EQU     H'0FFF'



;	__CONFIG        _BODEN_OFF & _CP_OFF & _DATA_CP_OFF & _PWRTE_ON & _WDT_OFF & _LVP_OFF & _MCLRE_ON & _INTRC_OSC_NOCLKOUT

_U001			     EQU     B'000000011000'		;MCLR enabled

	__CONFIG        _U001

;==========================================================================
;       Variable Definition
;==========================================================================
TIMER1		EQU	H'08'		;Used in delay routine
TIMER2		EQU	H'09'		; "	"	"	

tt1		EQU	H'0A'
tt2		EQU	H'0B'
tt3		EQU	H'0C'

fnc1		EQU	H'0D'		;standard run / switch off
;==========================================================================

		ORG	0		;Reset vector address
		GOTO	RESET		;goto RESET routine when boot.

;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;
;	       **********************************
;              **  RESET :  main boot routine  **
;              **********************************

RESET		nop
;
		MOVLW	B'11010111'	;Set PIC options (See datasheet Pg.22).
		option			;Write the OPTION register.
;
;		clrf	OSCCAL		;not needed - after reset value is 1111 1110
;
		MOVLW	B'11111000'
		tris	GPIO


; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; XXXXXXXXXX       main            XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

		clrf	GPIO

		btfsc	fnc1,D'000'
		goto	sw_off

		bsf	fnc1,D'000'		;next time after reset: switch off function

;standard start-up
		call	test01f
		call	test01f
		call	test01f
		call	test01f
;
		call	test02f
		call	test02f
		call	test02f
		call	test02f
;
;--- main routine ---
;
		movlw	D'006'			;6 x zhruba 10 min = zhruba hodka.
		movwf	tt3
;
ml2		movlw	D'013'			;013 = 13x46 sec -> ~ 10 min (9,5 min).
		movwf	tt2
;
ml1		movlw	D'255'			;255 = 46 sec
		movwf	tt1
;
ml0		movlw	B'00000001'
		movwf	GPIO
		call	dr5
;
		movlw	B'00000010'
		movwf	GPIO
		call	dr5
;
		movlw	B'00000100'
		movwf	GPIO
		call	dr5
;
		decfsz	tt1,F
		goto	ml0
		decfsz	tt2,F
		goto	ml1
		decfsz	tt3,F
		goto	ml2

fin2		clrf	GPIO
		clrf	fnc1		;standard start next time after reset
;--------------------------------------------------------------------
finito		sleep
;
		goto	finito
;--------------------------------------------------------------------
;--------------------------------------------------------------------
sw_off		clrf	fnc1		;standard start next time after reset

		call	test01
		call	test02
		call	test01
		call	test02

		goto	fin2
;--------------------------------------------------------------------
;--------------------------------------------------------------------
;--------------------------------------------------------------------
test01		movlw	B'00000001'
		movwf	GPIO
		CALL	dr1
;
		movlw	B'00000010'
		movwf	GPIO
		CALL	dr1
;
		movlw	B'00000100'
		movwf	GPIO
		CALL	dr1
;
		movlw	B'00000000'
		movwf	GPIO
		CALL	dr1
;
		retlw	0
;-------------------------------------------------------------------
test02		movlw	B'00000111'
		movwf	GPIO
		CALL	dr1
;
		movlw	B'00000000'
		movwf	GPIO
		CALL	dr1
;
		retlw	0

;--------------------------------------------------------------------
test01f		movlw	B'00000001'
		movwf	GPIO
		CALL	dr1f
;
		movlw	B'00000010'
		movwf	GPIO
		CALL	dr1f
;
		movlw	B'00000100'
		movwf	GPIO
		CALL	dr1f
;
		movlw	B'00000000'
		movwf	GPIO
		CALL	dr1f
;
		retlw	0
;-------------------------------------------------------------------
test02f		movlw	B'00000111'
		movwf	GPIO
		CALL	dr1f
;
		movlw	B'00000000'
		movwf	GPIO
		CALL	dr1f
;
		retlw	0

;----------------------------------------------------------------------------------------

;		*********************************************
;		*               delay routine               *
;		*********************************************

;----------------------------------------------------------------------------
dr5		MOVLW   D'070'
		MOVWF   TIMER2
DEL_LOOP3_1	MOVLW   D'255'
		MOVWF   TIMER1

DEL_LOOP3_2	DECFSZ  TIMER1,F
                GOTO    DEL_LOOP3_2
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP3_1
		retlw	0
;----------------------------------------------------------------------------
dr1		MOVLW   D'255'
		MOVWF   TIMER2
DEL_LOOP3_1b	MOVLW   D'255'
		MOVWF   TIMER1

DEL_LOOP3_2b	DECFSZ  TIMER1,F
                GOTO    DEL_LOOP3_2b
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP3_1b
		retlw	0
;----------------------------------------------------------------------------
dr1f		MOVLW   D'100'
		MOVWF   TIMER2
DEL_LOOP3_1f	MOVLW   D'255'
		MOVWF   TIMER1

DEL_LOOP3_2f	DECFSZ  TIMER1,F
                GOTO    DEL_LOOP3_2f
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP3_1f
		retlw	0

;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX


		END